import { useState, useEffect } from 'react'
import withLayout from '@/layout'
import { ScrollView, Input, Image, Block, Picker } from '@tarojs/components'
import '@/assets/css/iconfont.css'
import { getCardList } from '@/services/card'
import './index.scss'

export default withLayout((props) => {

  const { router } = props
  const { name, buildingId, type } = router.params

  const RenChouData = {
    name,
    realtyConsultant: '',
    remark: ''
  }

  const QianYueData = {
    name,
    realtyConsultant: '',
    remark: ''
  }

  const JieYongData = {
    name,
    realtyConsultant: '',
    remark: ''
  }

  const [FormData, setFormData] = useState({ ...RenChouData })

  const [ConsultantList, setConsultantList] = useState([])
  const [CurrnetConsultant, setCurrnetConsultant] = useState({})

  const [StatusList] = useState([
    { name: '认筹', id: 3 },
    { name: '签约', id: 4 },
    { name: '结佣', id: 5 },
  ])
  const [CurrentStatusId, setCurrentStatusId] = useState(3)

  const [RoomTypeList] = useState([
    { name: '二室一厅', id: 1 },
    { name: '三室二厅', id: 2 },
    { name: '三室一厅', id: 3 },
    { name: '四室二厅', id: 4 }
  ])
  const [CurrentRoomTypeId, setCurrentRoomTypeId] = useState(null)

  useEffect(() => {
    if (buildingId) {
      const params = {
        pageNumber: 1,
        pageSize: 50,
        buildingId,
      }
      getCardList(params).then((res) => {
        const { records } = res
        setConsultantList(records || [])
      })
    }
  }, [buildingId])

  const CutStatus = (item) => {
    return () => {
      setCurrentStatusId(item.id)
    }
  }

  const CutRoomType = (item) => {
    return () => {
      setCurrentRoomTypeId(item.id === CurrentRoomTypeId ? null : item.id)
    }
  }

  const InputChange = (key, e) => {
    let resData = FormData
    resData[key] = e.detail.value
    setFormData(resData)
  }

  const PickerChange = (key, e) => {
    let resData = FormData
    if (key === 'realtyConsultant') {
      resData[key] = ConsultantList[e.detail.value].id
      resData.realtyConsultantName = ConsultantList[e.detail.value].name
      setCurrnetConsultant(ConsultantList[e.detail.value])
    }
    setFormData(resData)
  }

  return (
    <view className='Page changeVisit'>

      <ScrollView scroll-y>
        <view className='PageContent'>

          <text className='required'>变更状态</text>
          <view className='FormLine flex-h'>
            <view className='flex-item'>
              <view className='CheckBoxList'>
                {
                  StatusList.map((item, index) => (
                    <view key={`StatusItem-${index}`} onClick={CutStatus(item)}>
                      <text>{item.name}</text>
                      {
                        CurrentStatusId === item.id &&
                        <Image mode='widthFix' src={require('@/assets/findHouse-icon1.png')}></Image>
                      }
                    </view>
                  ))
                }
              </view>
            </view>
          </view>

          {
            CurrentStatusId === 3 &&
            <Block>
              <text className='required'>客户姓名</text>
              <view className='FormLine flex-h'>
                <view className='flex-item'>
                  <Input placeholder='请输入姓名' value={FormData.name} onInput={InputChange.bind(this, 'name')}></Input>
                </view>
              </view>
            </Block>
          }

          {
            CurrentStatusId === 3 &&
            <Block>
              <text>归属渠道</text>
              <view className='FormLine flex-h'>
                <view className='flex-item'>
                  <Input placeholder='请输入渠道' disabled value={type === 'customer' ? '-' : ''}></Input>
                </view>
              </view>
            </Block>
          }

          {
            CurrentStatusId === 3 &&
            <Block>
              <text className='required'>内场接待</text>
              <view className='FormLine flex-h'>
                <view className='flex-item'>
                  <Picker range-key='name' range={ConsultantList} value={0} onChange={PickerChange.bind(this, 'realtyConsultant')}>{CurrnetConsultant.name || '请选择'}</Picker>
                </view>
              </view>
            </Block>
          }

          <text className='required'>业绩分成人|占比/%</text>
          <view className='FormLine flex-h'>
            <view className='flex-item'>
              <Input placeholder='请输入业绩分成人|占比/%'></Input>
            </view>
          </view>

          <text className='required'>户型</text>
          <view className='FormLine flex-h'>
            <view className='flex-item'>
              <view className='CheckBoxList'>
                {
                  RoomTypeList.map((item, index) => (
                    <view key={`RoomTypeItem-${index}`} onClick={CutRoomType(item)}>
                      <text>{item.name}</text>
                      {
                        CurrentRoomTypeId === item.id &&
                        <Image mode='widthFix' src={require('../../../assets/findHouse-icon1.png')}></Image>
                      }
                    </view>
                  ))
                }
              </view>
            </view>
          </view>

          <text className='required'>房号</text>
          <view className='FormLine flex-h'>
            <view className='flex-item'>
              <Input placeholder='请输入房号'></Input>
            </view>
          </view>

          <text className='required'>签约日期</text>
          <view className='FormLine flex-h'>
            <view className='flex-item'>
              <text>请选择</text>
            </view>
            <text className='iconfont icon-jiantoudown'></text>
          </view>

          <text className='required'>成交金额</text>
          <view className='FormLine flex-h'>
            <view className='flex-item'>
              <Input placeholder='请输入金额'></Input>
            </view>
          </view>

          <text>备注</text>
          <view className='FormLine flex-h'>
            <view className='flex-item'>
              <Input placeholder='补充说明（选填）'></Input>
            </view>
          </view>

          <view className='Btn'>
            <text>提交</text>
          </view>

        </view>
      </ScrollView>

    </view>
  )
})
